pub struct OrganizationMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on organization resources.
It is not used directly, but through the PolicySimulator hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_policysimulator1 as policysimulator1;
use policysimulator1::{PolicySimulator, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = PolicySimulator::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `locations_access_policy_simulations_operations_get(...)`, `locations_org_policy_violations_previews_create(...)`, `locations_org_policy_violations_previews_get(...)`, `locations_org_policy_violations_previews_list(...)`, `locations_org_policy_violations_previews_operations_get(...)`, `locations_org_policy_violations_previews_org_policy_violations_list(...)`, `locations_replays_create(...)`, `locations_replays_get(...)`, `locations_replays_operations_get(...)`, `locations_replays_operations_list(...)` and `locations_replays_results_list(...)`
// to build up your call.
let rb = hub.organizations();Implementations
Sourceimpl<'a, C> OrganizationMethods<'a, C>
impl<'a, C> OrganizationMethods<'a, C>
Sourcepub fn locations_access_policy_simulations_operations_get(
&self,
name: &str,
) -> OrganizationLocationAccessPolicySimulationOperationGetCall<'a, C>
pub fn locations_access_policy_simulations_operations_get( &self, name: &str, ) -> OrganizationLocationAccessPolicySimulationOperationGetCall<'a, C>
Create a builder to help you perform the following task:
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
Arguments
name- The name of the operation resource.
Sourcepub fn locations_org_policy_violations_previews_operations_get(
&self,
name: &str,
) -> OrganizationLocationOrgPolicyViolationsPreviewOperationGetCall<'a, C>
pub fn locations_org_policy_violations_previews_operations_get( &self, name: &str, ) -> OrganizationLocationOrgPolicyViolationsPreviewOperationGetCall<'a, C>
Create a builder to help you perform the following task:
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
Arguments
name- The name of the operation resource.
Sourcepub fn locations_org_policy_violations_previews_org_policy_violations_list(
&self,
parent: &str,
) -> OrganizationLocationOrgPolicyViolationsPreviewOrgPolicyViolationListCall<'a, C>
pub fn locations_org_policy_violations_previews_org_policy_violations_list( &self, parent: &str, ) -> OrganizationLocationOrgPolicyViolationsPreviewOrgPolicyViolationListCall<'a, C>
Create a builder to help you perform the following task:
ListOrgPolicyViolations lists the OrgPolicyViolations that are present in an OrgPolicyViolationsPreview.
Arguments
parent- Required. The OrgPolicyViolationsPreview to get OrgPolicyViolations from. Format: organizations/{organization}/locations/{location}/orgPolicyViolationsPreviews/{orgPolicyViolationsPreview}
Sourcepub fn locations_org_policy_violations_previews_create(
&self,
request: GoogleCloudPolicysimulatorV1OrgPolicyViolationsPreview,
parent: &str,
) -> OrganizationLocationOrgPolicyViolationsPreviewCreateCall<'a, C>
pub fn locations_org_policy_violations_previews_create( &self, request: GoogleCloudPolicysimulatorV1OrgPolicyViolationsPreview, parent: &str, ) -> OrganizationLocationOrgPolicyViolationsPreviewCreateCall<'a, C>
Create a builder to help you perform the following task:
CreateOrgPolicyViolationsPreview creates an OrgPolicyViolationsPreview for the proposed changes in the provided OrgPolicyViolationsPreview.OrgPolicyOverlay. The changes to OrgPolicy are specified by this OrgPolicyOverlay. The resources to scan are inferred from these specified changes.
Arguments
request- No description provided.parent- Required. The organization under which this OrgPolicyViolationsPreview will be created. Example:organizations/my-example-org/locations/global
Sourcepub fn locations_org_policy_violations_previews_get(
&self,
name: &str,
) -> OrganizationLocationOrgPolicyViolationsPreviewGetCall<'a, C>
pub fn locations_org_policy_violations_previews_get( &self, name: &str, ) -> OrganizationLocationOrgPolicyViolationsPreviewGetCall<'a, C>
Create a builder to help you perform the following task:
GetOrgPolicyViolationsPreview gets the specified OrgPolicyViolationsPreview. Each OrgPolicyViolationsPreview is available for at least 7 days.
Arguments
name- Required. The name of the OrgPolicyViolationsPreview to get.
Sourcepub fn locations_org_policy_violations_previews_list(
&self,
parent: &str,
) -> OrganizationLocationOrgPolicyViolationsPreviewListCall<'a, C>
pub fn locations_org_policy_violations_previews_list( &self, parent: &str, ) -> OrganizationLocationOrgPolicyViolationsPreviewListCall<'a, C>
Create a builder to help you perform the following task:
ListOrgPolicyViolationsPreviews lists each OrgPolicyViolationsPreview in an organization. Each OrgPolicyViolationsPreview is available for at least 7 days.
Arguments
parent- Required. The parent the violations are scoped to. Format:organizations/{organization}/locations/{location}Example:organizations/my-example-org/locations/global
Sourcepub fn locations_replays_operations_get(
&self,
name: &str,
) -> OrganizationLocationReplayOperationGetCall<'a, C>
pub fn locations_replays_operations_get( &self, name: &str, ) -> OrganizationLocationReplayOperationGetCall<'a, C>
Create a builder to help you perform the following task:
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
Arguments
name- The name of the operation resource.
Sourcepub fn locations_replays_operations_list(
&self,
name: &str,
) -> OrganizationLocationReplayOperationListCall<'a, C>
pub fn locations_replays_operations_list( &self, name: &str, ) -> OrganizationLocationReplayOperationListCall<'a, C>
Create a builder to help you perform the following task:
Lists operations that match the specified filter in the request. If the server doesn’t support this method, it returns UNIMPLEMENTED.
Arguments
name- The name of the operation’s parent resource.
Sourcepub fn locations_replays_results_list(
&self,
parent: &str,
) -> OrganizationLocationReplayResultListCall<'a, C>
pub fn locations_replays_results_list( &self, parent: &str, ) -> OrganizationLocationReplayResultListCall<'a, C>
Create a builder to help you perform the following task:
Lists the results of running a Replay.
Arguments
parent- Required. The Replay whose results are listed, in the following format:{projects|folders|organizations}/{resource-id}/locations/global/replays/{replay-id}Example:projects/my-project/locations/global/replays/506a5f7f-38ce-4d7d-8e03-479ce1833c36
Sourcepub fn locations_replays_create(
&self,
request: GoogleCloudPolicysimulatorV1Replay,
parent: &str,
) -> OrganizationLocationReplayCreateCall<'a, C>
pub fn locations_replays_create( &self, request: GoogleCloudPolicysimulatorV1Replay, parent: &str, ) -> OrganizationLocationReplayCreateCall<'a, C>
Create a builder to help you perform the following task:
Creates and starts a Replay using the given ReplayConfig.
Arguments
request- No description provided.parent- Required. The parent resource where this Replay will be created. This resource must be a project, folder, or organization with a location. Example:projects/my-example-project/locations/global
Sourcepub fn locations_replays_get(
&self,
name: &str,
) -> OrganizationLocationReplayGetCall<'a, C>
pub fn locations_replays_get( &self, name: &str, ) -> OrganizationLocationReplayGetCall<'a, C>
Create a builder to help you perform the following task:
Gets the specified Replay. Each Replay is available for at least 7 days.
Arguments
name- Required. The name of the Replay to retrieve, in the following format:{projects|folders|organizations}/{resource-id}/locations/global/replays/{replay-id}, where{resource-id}is the ID of the project, folder, or organization that owns theReplay. Example:projects/my-example-project/locations/global/replays/506a5f7f-38ce-4d7d-8e03-479ce1833c36